@@ -2,6 +2,7 @@
 from __future__ import unicode_literals
 from functools import update_wrapper
 
+from django.core.exceptions import ImproperlyConfigured
 from django.contrib import admin
 from django.http import Http404, HttpResponse
 from django.core.exceptions import PermissionDenied
@@ -14,23 +15,28 @@ class DraftAdmin(admin.ModelAdmin):
     Mixin with draft view support
     """
     def get_urls(self):
-        from django.conf.urls import patterns, url
+        from django.conf.urls import url
 
         def wrap(view):
             def wrapper(*args, **kwargs):
                 return self.admin_site.admin_view(view)(*args, **kwargs)
             return update_wrapper(wrapper, view)
 
+        if not hasattr(self.model, 'get_absolute_url'):
+            raise ImproperlyConfigured(
+                "The model %s should have `.get_absolute_url` method "
+                "to make possible to use the light-draft feature." % self.model
+            )
+
         info = self.model._meta.app_label, self.model._meta.model_name
 
-        if not hasattr(self.model, 'get_draft_url'):
-            super(DraftAdmin, self).get_urls()
-
-        return patterns('',
-                        url(r'^(.+)/preview/$',
-                            wrap(self.preview_view),
-                            name='%s_%s_preview' % info),
-                        ) + super(DraftAdmin, self).get_urls()
+        return [
+            url(
+                r'^(.+)/preview/$',
+                wrap(self.preview_view),
+                name='%s_%s_preview' % info
+            ),
+        ] + super(DraftAdmin, self).get_urls()
 
     def preview_view(self, request, *args, **kwargs):
         model = self.model
@@ -45,24 +51,20 @@ class DraftAdmin(admin.ModelAdmin):
         if request.method != 'POST':
             raise Http404
 
-        print(request.POST)
-
-
         # Work with related formsets (collection instances)
-        inline_instances = self.get_inline_instances(request, obj)
         prefixes = {}
         items = {}
-        for FormSet, inline in zip(self.get_formsets(request, obj), inline_instances):
-            prefix = FormSet.get_default_prefix()
+        for formset, inline in self.get_formsets_with_inlines(request, obj):
+            prefix = formset.get_default_prefix()
             prefixes[prefix] = prefixes.get(prefix, 0) + 1
             if prefixes[prefix] != 1 or not prefix:
                 prefix = "%s-%s" % (prefix, prefixes[prefix])
 
-            formset = FormSet(request.POST, request.FILES,
+            formset = formset(request.POST, request.FILES,
                               instance=obj, prefix=prefix,
                               queryset=inline.get_queryset(request))
 
-            items[FormSet.get_default_prefix()] = [
+            items[formset.get_default_prefix()] = [
                 f.save(commit=False) for f in formset
                 if f.is_valid()]
 
@@ -72,7 +74,11 @@ class DraftAdmin(admin.ModelAdmin):
         if form.is_valid():
             # Also proccess m2m fields
             opts = form.instance._meta
-            for f in opts.many_to_many + opts.virtual_fields:
+
+            # Model._meta.virtual_fields is removed in Django 2.0.x
+            virtual_fields = getattr(opts, 'virtual_fields', [])
+
+            for f in tuple(opts.many_to_many) + tuple(virtual_fields):
                 if not hasattr(f, 'save_form_data'):
                     continue
                 if form._meta.fields and f.name not in form._meta.fields:
@@ -92,6 +98,5 @@ class DraftAdmin(admin.ModelAdmin):
 
         return HttpResponse(str(form.errors))
 
-
     class Media:
         js = ('admin/light.draft.js',)
